<?php

namespace Drupal\ppss;

use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\Config\ConfigFactoryInterface;
use Stripe\StripeClient;

/**
 *
 * Service Api.
 *
 */
class PPSSServiceApi
{

  /**
   * Drupal\Core\Config\ConfigFactory definition.
   *
   * @var \Drupal\Core\Config\ConfigFactory
   */
  protected $configFactory;

  public function __construct(ConfigFactoryInterface $config_factory)
  {
    $this->config = $config_factory->get('ppss.settings');
  }

  /**
   *  Send emails to the customer about their subscription
   * 
   *  @param string $user_email
   *  User email.
   *  @param string $type
   *  Type mail.
   *  @param string $finish_date
   *  Subscription end date.
   *
   */
  public function sendEmail($user_email, $type, $finish_date)
  {
    if($this->config->get($type)) {
      $module = 'ppss';
      $key = 'ppss_email';
      $to = $user_email.";".\Drupal::config('system.site')->get('mail');
      $langcode = \Drupal::currentUser()->getPreferredLangcode();
      $send = true;
      switch($type) {
        case 'mail_canceled_subject':
          $params['subject'] = $this->config->get('mail_canceled_subject');
          $params['message'] = $this->config->get('mail_canceled_body');
          break;
        case 'mail_scheduled_cancellation_subject':
          $params['subject'] = $this->config->get('mail_scheduled_cancellation_subject');
          $body = $this->config->get('mail_scheduled_cancellation_body');
          $params['message'] = str_replace("[finish-date]", date('d/m/Y', $finish_date), $body);
          break;
        default:
          Drupal::logger('PPSS')->info('Received unknown mail');
      }
      $result = \Drupal::service('plugin.manager.mail')->mail($module, $key, $to, $langcode, $params, NULL, $send);
      if ($result['result']) {
        \Drupal::logger('PPSS')->info('An email notification has been sent to @email ', array('@email' => $to));
      } else {
        \Drupal::logger('PPSS')->error('There was a problem sending your message and it was not sent @email.', array('@email' => $to));
      }
    }
  }

  /**
   * Unpublish all user ads
   *
   * @param integer $uid
   *   User id.
   * @param string $expire
   *   Date to unpublish content.
   */
  public function unpublishNodes($uid, $expire) {
    //get all user ads
    $nids = \Drupal::entityQuery("node")->condition('uid', $uid)->condition('status', 1)->execute();
    $entity = \Drupal::entityTypeManager()->getStorage("node");
    $nodes = $entity->loadMultiple($nids);

    foreach ($nodes as $node) {
      $node->unpublish_on = $expire;
      $node->save();
    }
  }

}
